Class: Async::WebDriver::Bridge::ProcessDriver
- Defined in:
- lib/async/webdriver/bridge/process_group.rb
Overview
A driver wrapper that closes an associated process handle.
Instance Attribute Summary
Attributes inherited from Driver
Instance Method Summary collapse
-
#close ⇒ Object
Close the driver and its process group.
-
#initialize(endpoint, process) ⇒ ProcessDriver
constructor
Initialize a process-backed driver.
Methods inherited from Driver
#The status of the driver after a connection has been established.=, #client, #closed?, #concurrency, #endpoint, #ephemeral_port, #port, #reusable?, #start, #viable?
Constructor Details
#initialize(endpoint, process) ⇒ ProcessDriver
Initialize a process-backed driver.
83 84 85 86 87 |
# File 'lib/async/webdriver/bridge/process_group.rb', line 83 def initialize(endpoint, process) super(endpoint) @process = process end |
Instance Method Details
#close ⇒ Object
Close the driver and its process group.
90 91 92 93 94 95 96 97 |
# File 'lib/async/webdriver/bridge/process_group.rb', line 90 def close super if @process @process.close @process = nil end end |